from flask import Flask
app = Flask(__name__)

@app.route('/')
def home():
    return """
    <head>
  <meta charset="UTF-8">
  <title>Hacking Program</title>
  <style>
  @font-face {
    font-family: 'Source Code Pro';
    font-style: normal;
    font-weight: 400;
    src: local('Source Code Pro'), local('SourceCodePro-Regular'), url(http://themes.googleusercontent.com/static/fonts/sourcecodepro/v4/mrl8jkM18OlOQN8JLgasDxM0YzuT7MdOe03otPbuUS0.woff) format('woff');
  }
  
  body {
      font-family: Source Code Pro;
      background:#000;
      color: #00FF00;
      margin:0;
      font-size: 13px;
  }
  canvas {
      position:absolute;
      top:0;
      left:0;
  }
  .bars-and-stuff{
      left:66.6%;
  }
  
  .output-console {
      position:fixed;
      overflow:hidden;
  }
  p{
    margin:0
    }</style>

</head>
<body>
<!-- partial:index.partial.html -->
<canvas class='hacker-3d-shiz'></canvas>
<canvas class='bars-and-stuff'></canvas>
<div class="output-console"></div>
<!-- partial -->
  <script>
    var canvas = document.querySelector(".hacker-3d-shiz"),
    ctx = canvas.getContext("2d"),
    canvasBars = document.querySelector(".bars-and-stuff"),
    ctxBars = canvasBars.getContext("2d"),
    outputConsole = document.querySelector(".output-console");

canvas.width = (window.innerWidth/3)*2;
canvas.height = window.innerHeight / 3;

canvasBars.width = window.innerWidth/3;
canvasBars.height = canvas.height;

outputConsole.style.height = (window.innerHeight / 3) * 2 + 'px';
outputConsole.style.top = window.innerHeight / 3 + 'px'


/* Graphics stuff */
function Square(z) {
    this.width = canvas.width/2;
    
    if(canvas.height < 200){
      this.width = 200;
    };
  
    this.height = canvas.height;
    z = z || 0;

    this.points = [
    new Point({
        x: (canvas.width / 2) - this.width,
        y: (canvas.height / 2) - this.height,
        z: z
    }),
    new Point({
        x: (canvas.width / 2) + this.width,
        y: (canvas.height / 2) - this.height,
        z: z
    }),
    new Point({
        x: (canvas.width / 2) + this.width,
        y: (canvas.height / 2) + this.height,
        z: z
    }),
    new Point({
        x: (canvas.width / 2) - this.width,
        y: (canvas.height / 2) + this.height,
        z: z
    })];
    this.dist = 0;
}

Square.prototype.update = function () {
    for (var p = 0; p < this.points.length; p++) {
        this.points[p].rotateZ(0.001);
        this.points[p].z -= 3;
        if (this.points[p].z < -300) {
            this.points[p].z = 2700;
        }
        this.points[p].map2D();
    }
}

Square.prototype.render = function () {
    ctx.beginPath();
    ctx.moveTo(this.points[0].xPos, this.points[0].yPos);
    for (var p = 1; p < this.points.length; p++) {
        if (this.points[p].z > -(focal - 50)) {
            ctx.lineTo(this.points[p].xPos, this.points[p].yPos);
        }
    }

    ctx.closePath();
    ctx.stroke();

    this.dist = this.points[this.points.length - 1].z;

};

function Point(pos) {
    this.x = pos.x - canvas.width / 2 || 0;
    this.y = pos.y - canvas.height / 2 || 0;
    this.z = pos.z || 0;

    this.cX = 0;
    this.cY = 0;
    this.cZ = 0;

    this.xPos = 0;
    this.yPos = 0;
    this.map2D();
}

Point.prototype.rotateZ = function (angleZ) {
    var cosZ = Math.cos(angleZ),
        sinZ = Math.sin(angleZ),
        x1 = this.x * cosZ - this.y * sinZ,
        y1 = this.y * cosZ + this.x * sinZ;

    this.x = x1;
    this.y = y1;
}

Point.prototype.map2D = function () {
    var scaleX = focal / (focal + this.z + this.cZ),
        scaleY = focal / (focal + this.z + this.cZ);

    this.xPos = vpx + (this.cX + this.x) * scaleX;
    this.yPos = vpy + (this.cY + this.y) * scaleY;
};

// Init graphics stuff
var squares = [],
    focal = canvas.width / 2,
    vpx = canvas.width / 2,
    vpy = canvas.height / 2,
    barVals = [],
    sineVal = 0;

/* fake console stuff */
var commandStart = ['Performing DNS Lookups for', 
                'Searching ', 
                'Analyzing ', 
                'Estimating Approximate Location of ', 
                'Compressing ', 
                'Requesting Authorization From : ', 
                'wget -a -t ', 
                'tar -xzf ', 
                'Entering Location ', 
                'Compilation Started of ',
                 'Downloading '],
    commandParts = ['Data Structure', 
                    'http://wwjd.com?au&2', 
                    'Texture', 
                    'TPS Reports', 
                    ' .... Searching ... ', 
                    'http://zanb.se/?23&88&far=2', 
                    'http://ab.ret45-33/?timing=1ww'],
    commandResponses = ['Authorizing ', 
                 'Authorized...', 
                 'Access Granted..', 
                 'Going Deeper....', 
                 'Compression Complete.', 
                 'Compilation of Data Structures Complete..', 
                 'Entering Security Console...', 
                 'Encryption Unsuccesful Attempting Retry...', 
                 'Waiting for response...', 
                 '....Searching...', 
                 'Calculating Space Requirements '
                ],
    isProcessing = false,
    processTime = 0,
    lastProcess = 0;


function render() {
    ctx.clearRect(0, 0, canvas.width, canvas.height);

    squares.sort(function (a, b) {
        return b.dist - a.dist;
    });
    for (var i = 0, len = squares.length; i < len; i++) {
        squares[i].update();
        squares[i].render();
    }
    
    ctxBars.clearRect(0, 0, canvasBars.width, canvasBars.height);
    
    ctxBars.beginPath();
    var y = canvasBars.height/6;
    ctxBars.moveTo(0,y);
    
    for(i = 0; i < canvasBars.width; i++){
        var ran = (Math.random()*20)-10;
        if(Math.random() > 0.98){
             ran = (Math.random()*50)-25   
        }
        ctxBars.lineTo(i, y + ran);
    }
    
    ctxBars.stroke();
    
    for(i = 0; i < canvasBars.width; i+=20){
        if(!barVals[i]){
            barVals[i] = {
                val : Math.random()*(canvasBars.height/2),
                freq : 0.1,
                sineVal : Math.random()*100
            };
        }
        
        barVals[i].sineVal+=barVals[i].freq;
        barVals[i].val+=Math.sin(barVals[i].sineVal*Math.PI/2)*5;
        ctxBars.fillRect(i+5,canvasBars.height,15,-barVals[i].val);
    }
    
    requestAnimationFrame(render);
}

function consoleOutput(){
    var textEl = document.createElement('p');
    
    if(isProcessing){
        textEl = document.createElement('span');
        textEl.textContent += Math.random() + " ";
        if(Date.now() > lastProcess + processTime){
            isProcessing = false;   
        }
    }else{
        var commandType = ~~(Math.random()*4);
        switch(commandType){
            case 0:
                textEl.textContent = commandStart[~~(Math.random()*commandStart.length)] + commandParts[~~(Math.random()*commandParts.length)];
                break;
            case 3: 
                isProcessing = true;
                processTime = ~~(Math.random()*5000);
                lastProcess = Date.now();
            default:
                 textEl.textContent = commandResponses[~~(Math.random()*commandResponses.length)];
            break;
        }
    }

    outputConsole.scrollTop = outputConsole.scrollHeight;
    outputConsole.appendChild(textEl);
    
    if (outputConsole.scrollHeight > window.innerHeight) {
       var removeNodes = outputConsole.querySelectorAll('*');
       for(var n = 0; n < ~~(removeNodes.length/3); n++){
            outputConsole.removeChild(removeNodes[n]);
        }
    }
    
    setTimeout(consoleOutput, ~~(Math.random()*200));
}


setTimeout(function(){   
      canvas.width = (window.innerWidth/3)*2;
      canvas.height = window.innerHeight / 3;

      canvasBars.width = window.innerWidth/3;
      canvasBars.height = canvas.height;

      outputConsole.style.height = (window.innerHeight / 3) * 2 + 'px';
      outputConsole.style.top = window.innerHeight / 3 + 'px';
  
      focal = canvas.width / 2;
      vpx = canvas.width / 2;
      vpy = canvas.height / 2;

      for (var i = 0; i < 15; i++) {
          squares.push(new Square(-300 + (i * 200)));
      }
  
      ctx.strokeStyle = ctxBars.strokeStyle = ctxBars.fillStyle = '#00FF00';
  
      render();
      consoleOutput();
}, 200);

window.addEventListener('resize', function(){
      canvas.width = (window.innerWidth/3)*2;
      canvas.height = window.innerHeight / 3;

      canvasBars.width = window.innerWidth/3;
      canvasBars.height = canvas.height;

      outputConsole.style.height = (window.innerHeight / 3) * 2 + 'px';
      outputConsole.style.top = window.innerHeight / 3 + 'px';
  
      focal = canvas.width / 2;
      vpx = canvas.width / 2;
      vpy = canvas.height / 2;
      ctx.strokeStyle = ctxBars.strokeStyle = ctxBars.fillStyle = '#00FF00';
});
  </script>

</body>"""

def webHack():
    app.run()




import time
import colorama
from colorama import Fore, Back, Style

colorama.init(autoreset=True)

def fakeTerminalHack(): 
    def typing(word):
        for char in word:
            time.sleep(.1)
            print(char, end='')
        print("")

    def dump_password(username,password):
        print(Fore.CYAN+username+":"+Fore.RED+password+Fore.WHITE)    

    def dump_hash(username,hash):
        print(Fore.CYAN+username+":500:aad3b435b51404eeaad3b435b51404ee:"+Fore.RED+hash+Fore.CYAN+":::")    

    def typing(command):
        for char in command:
            time.sleep(.1)
            print(char, end='')
        print("")

    def meterpreter(command):
        print(Fore.GREEN+"meterpreter > ", end="", flush=True)
        for char in command:
            time.sleep(.1)
            print(char, end='')
        print("")

    def meterpreter_rdp(command):
        print(Fore.GREEN+"meterpreter post("+Fore.RED+"enable_rdp"+Fore.GREEN+") > ", end="", flush=True)
        for char in command:
            time.sleep(.1)
            print(char, end='')
        print("")

    # Start

    print("")
    time.sleep(1)
    print(Fore.GREEN + "[msf]("+Fore.YELLOW+"Jobs:"+Fore.GREEN+"0 "+Fore.LIGHTBLUE_EX+"Agents:"+Fore.GREEN+"0) exploit("+Fore.RED+"multi/handler"+Fore.GREEN+") >> ", end="", flush=True)
    time.sleep(1)
    typing("exploit")
    time.sleep(1)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Started reverse TCP handler on 10.0.2.15:4444")
    time.sleep(3)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Sending stage (980808 bytes) to 10.10.146.10")
    time.sleep(1)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Meterpreter session 1 opened (10.0.2.15:4444 → 10.10.146.10:33396)")
    print("")
    time.sleep(1)
    meterpreter("getuid")
    time.sleep(1)
    print("")
    print(Fore.CYAN+"Server username: LAPTOP-67FLDS23U\JoeBlogs")
    print("")
    time.sleep(1)
    meterpreter("ipconfig")
    time.sleep(1)
    print(Fore.CYAN+"""
    MS TCP Loopback interface
    Hardware MAC: 00:00:00:00:00:00
    IP Address  : 127.0.0.1
    Netmask     : 255.0.0.0
    AMD PCNET Family PCI Ethernet Adapter - Packet Scheduler Miniport
    Hardware MAC: 00:0c:29:10:f5:15
    IP Address  : 10.10.146.10
    Netmask     : 255.255.0.0
    """)
    time.sleep(1)
    meterpreter("run killav")
    time.sleep(1)
    print("")
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Killing Antivirus services on the target...")
    time.sleep(1)
    print("")
    meterpreter("getsystem")
    print("")
    time.sleep(2)
    print(Fore.CYAN+"... got system via technique 1 (Named Pipe Impersonation (In Memory/Admin)).")
    print("")
    time.sleep(1)
    meterpreter("run post/windows/gather/hashdump")
    print("")
    time.sleep(3)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Obtaining the user list and keys...")
    time.sleep(.5)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Decrypting user keys...")
    time.sleep(.5)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Dumping cleartext passwords...")
    time.sleep(2)
    print("")
    dump_password("Administrator","1234567890")
    dump_password("JoeBlogs","password123!")
    print("")
    time.sleep(.5)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Dumping password hashes...")
    print("")
    time.sleep(2)
    dump_hash("Administrator","8AF326AA4850225B75C592D4CE19CCF5")
    dump_hash("JoeBlogs","8119935C5F7FA5F57135620C8073AACA")
    print("")
    time.sleep(1)
    meterpreter("use post/windows/manage/enable_rdp")
    time.sleep(1)
    meterpreter_rdp("set SESSION 1")
    time.sleep(.5)
    print(Fore.GREEN+"SESSION => 1")
    time.sleep(1)
    meterpreter_rdp("exploit")
    print("")
    time.sleep(2)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Enabling Remote Desktop")
    time.sleep(.5)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Opening port on local firewall...")
    time.sleep(.5)
    print(Fore.LIGHTBLUE_EX+"[*]"+Fore.GREEN+" Module Completed Successfully")
    time.sleep(1)
    print("")


from setuptools import setup, find_packages


VERSION = '0.2.8'
DESCRIPTION = 'A Python Package Full Of Fake Hacking Programs To Prank Your Friends'
LONG_DESCRIPTION = 'A Package That Lets You Easily Trick Your Friends And Prank Them With Fake Hacking Programs'

# Setting up
setup(
    name="hackprank",
    version=VERSION,
    author="Aarav Goel",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['rich', 'flask', 'pyfiglet', 'flask', 'colorama'],
    keywords=['python', 'hack', 'prank', 'cool', 'pyhacks', 'pyhack', 'pranks', 'hackprank', 'hackpranks'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)


import pyfiglet
from rich.console import Group
from rich.panel import Panel
from rich.console import Console
from rich.prompt import IntPrompt, Prompt
from rich.progress import Progress, track
from time import sleep
from os import *
from colorama import *
import random

def web_hacking():
    for x in track(range(25),"Initializing..."):
        sleep(0.1)
    url = Prompt.ask("Enter The Website's Url")
    for i in track(range(100), f"Bypassing Mainframe"):
        sleep(0.1)
    for i in track(range(100),f"Gathering Information On {url}"):
        sleep(0.1)
    with Progress(transient=True) as prog :
        exploiting = prog.add_task("Exploiting The Website",total=500)
        decoding = prog.add_task("Cracking The Passwords Hashes",total=300)
        dumping = prog.add_task("Dumping Plain Text Passwords",total=900)
        while not prog.finished:
            prog.update(exploiting,advance=0.9)
            prog.update(decoding,advance=0.3)
            prog.update(dumping,advance=0.5)
            sleep(0.1)
    con.print("Password: Password", style="bold green")
    with Progress(transient=True) as prog:
        code = prog.add_task("Entering Malicious Code To Website", total=300)
        capture = prog.add_task("Getting User Passwords", total = 500)
        change = prog.add_task("Changing All Passwords And Username To One Master Key", total=900)
        while not prog.finished:
            prog.update(capture,advance=0.9)
            prog.update(change,advance=0.3)
            prog.update(code,advance=0.5)
            sleep(0.1)
    con.print("Master Key: 0x1a23x", style="bold green")
    return

def Phishing_hack():
    for x in track(range(25),"Initializing..."):
        sleep(0.1)
    target = Prompt.ask("Enter The Target's Email Or Press [1] To Make A Phishing Site")  
    for i in track(range(100),f"Making Hook Script And Fake Logins"):
        sleep(0.1)
    with Progress(transient=True) as prog:
        exploiting = prog.add_task("Deploying Website",total=900)
        decoding = prog.add_task("Entering Malicious Scripts",total=500)
        while not prog.finished:
            prog.update(exploiting,advance=0.3)
            prog.update(decoding,advance=0.9)
            sleep(0.1)
    if target != "1":
        with Progress(transient=True) as prog:
            fake_account = prog.add_task("Making Fake Account As Google Security", total=500)
            encrypt = prog.add_task("Encrypting Email And Attaching Malicious Code", total=300)
            send_email = prog.add_task("Sending Email", total=900)
            while not prog.finished:
                prog.update(fake_account,advance=0.9)
                prog.update(send_email,advance=0.3)
                prog.update(encrypt,advance=0.5)
                sleep(0.1)
        con.print(f"Phishing Email Sent To {target}", style="bold green")
        return
    elif target == "1":
        con.print("Phising Site Domain: www.googlo.com", style="bold green")
        return

def WIFI_hack():
    for x in track(range(25),"Initializing..."):
        sleep(0.1)
    wifi = Prompt.ask("Enter The Wifi Name")
    for i in track(range(100), f"Bypassing Mainframe"):
        sleep(0.1)
    for i in track(range(100),f"Gathering Information On {wifi}"):
        sleep(0.1)
    with Progress(transient=True) as prog:
        exploiting = prog.add_task(f"Exploting {wifi}",total=500)
        script = prog.add_task("Entering Maliciouus Scripts",total=300)
        back_door = prog.add_task(f"Back Dooring {wifi}",total=900)
        while not prog.finished:
            prog.update(exploiting,advance=0.9)
            prog.update(back_door,advance=0.3)
            prog.update(script,advance=0.5)
            sleep(0.1)
    con.print(f"Wifi Password: password\nUsername{wifi}\nWifi Provider:Rogers Inc.", style="bold green")
    return

def find():
    for x in track(range(25),"Initializing..."):
        sleep(0.1)
    name = Prompt.ask("Enter The Target's Name")
    for i in track(range(100), f"Bypassing Mainframe"):
        sleep(0.1)
    for i in track(range(100),f"Gathering Information On {name}"):
        sleep(0.1)
    with Progress(transient=True) as prog:
        locate = prog.add_task(f"Locating {name}", total=300)
        exploiting = prog.add_task(f"Exploiting {name}", total=500)
        info = prog.add_task(f"Finding Info About {name}", total=900)
        while not prog.finished:
            prog.update(exploiting, advance=0.6)
            prog.update(info, advance=0.3)
            prog.update(locate, advance=0.5)
            sleep(0.1)
    with Progress(transient=True) as prog:
        master = prog.add_task("Gathering All Info Into One Master Key", total=500)
        while not prog.finished:
            prog.update(master, advance=0.5)
            sleep(0.1)
    con.print(f"Master Key: 0x1bx1a6x20 \nIP: {f'{random.randrange(125, 225)}.{random.randrange(1, 225)}.{random.randrange(1, 225)}.{random.randrange(1, 225)}'}", style="bold green")
    return
    

def remote():
    for x in track(range(25),"Initializing..."):
        sleep(0.1)
    ip = Prompt.ask("Enter The IP Of Target") 
    for i in track(range(100), f"Bypassing Mainframe"):
        sleep(0.1)
    for i in track(range(100),f"Gathering Information On {ip}"):
        sleep(0.1)
    with Progress(transient=True) as prog:
        info = prog.add_task("Getting Login Info", total=500)
        shutdown = prog.add_task(f"Shutting Down {ip}", total=900)
        while not prog.finished:
            prog.update(shutdown, advance=0.3)
            prog.update(info, advance=0.9)
            sleep(0.1)
    con.print(f"{ip} Successfully Shutdown", style="bold green")
    con.print(f"Username: professional\nPassword: password", style="bold green")
    return

def nuke():
    explode = """
                          ____/ (  (    )   )  \___
                       ((     (   )(    )  )   (   )  )
                     ((/  ( _(   )   (   _) ) (  () )  )
                    ( (  ( (_)   ((    (   )  .((_ ) .  )_
                   ( (  )    (      (  )    )   ) . ) (   )
                  (  (   (  (   ) (  _  ( _) ).  ) . ) ) ( )
                  ( (  (   ) (  )   (  ))     ) _)(   )  )  )
                 ( (  ( \ ) (    (_  ( ) ( )  )   ) )  )) ( )
                  (  (   (  (   (_ ( ) ( _    )  ) (  )  )   )
                 ( (  ( (  (  )     (_  )  ) )  _)   ) _( ( )
                  ((  (   )(    (     _    )   _) _(_ (  (_ )
                   (_((__(_(__(( ( ( |  ) ) ) )_))__))_)___)
                   ((__)        \\||lll|l||///          \_))
                            (   /(/ (  )  ) )\   )
                          (    ( ( ( | | ) ) )\   )
                           (   /(| / ( )) ) ) )) )
                         (     ( ((((_(|)_)))))     )
                          (      ||\(|(|)|/||     )
                        (        |(||(||)||||        )
                          (     //|/l|||)|\\ \     )
                        (/ / //  /|//||||\\  \ \  \ _)"""

    for x in track(range(25),"Initializing..."):
        sleep(0.1)      
    name = Prompt.ask("Enter The Target City's Name")
    nuke = Prompt.ask("Which Nuke Would You Like To Use")

    for x in track(range(100), "Bypassing Government Mainframe"):
        sleep(0.01)
    for x in track(range(100), f"Gathering Information About {nuke}"):
        sleep(0.01)
    with Progress(transient=True) as prog:
        locate = prog.add_task(f"Locating {nuke}", total=300)
        gHack = prog.add_task("Hacking Government Systems", total=500)
        nHack = prog.add_task("Hacking Into Nuclear Controls", total=900)
        while not prog.finished:
            prog.advance(locate, 0.9)
            prog.advance(gHack, 0.5)
            prog.advance(nHack, 0.3)
            sleep(0.1)
    con.print("Government Systems Have Been Hacked And You Now Have Access To Nuke Controls", style="bold green")
    with Progress(transient=True) as prog:
        verify = prog.add_task("Verifying Target Location", total=300)
        pLaunch = prog.add_task("Preparing For Launch", total=600)
        while not prog.finished:
            prog.advance(verify, 0.9)
            prog.advance(pLaunch, 0.5)
            sleep(0.1)
    con.print(f"{nuke.title()} Launched To {name}", style="bold green")

    con.print(explode, style="red")
    sleep(2)
    con.print("Target Location Successfully Eliminated")
    return


    



def hack():
    global con
    con = Console()

    banner = pyfiglet.figlet_format("Cypher",font="banner3-D")
    con.print(banner,"modern hacking framework to hack any possible device in the whole entire world",style="bold green")

    options = Group(
        Panel("1. Web App Hacking"),
        Panel("2. Phishing Attack"),
        Panel("3. WIFI Hacking"),
        Panel("4. Find User IP"),
        Panel("5. Remote Shutdown/Login")
    )
    con.print(Panel(options),style="bold green")


    answer = IntPrompt.ask("Which one do you pick? ",choices=['1','2','3','4','5','6'])

    if answer == 1:
        web_hacking()
    elif answer == 2:
        Phishing_hack()
    elif answer == 3:
        WIFI_hack()
    elif answer == 5:
        remote()
    elif answer == 4:
        find()          
    elif answer == 6:
        nuke()                     


